@@ -922,7 +922,6 @@ pub fn impl_widget_trait(ast: &DeriveInput) -> TokenStream {
 
             fn set_image<I: ImageExt>(&mut self, image: Option<I>) {
                 assert!(!self.was_deleted());
-                let _old_image = self.image();
                 if let Some(image) = image {
                     assert!(!image.was_deleted());
                     unsafe { #set_image(self.inner, image.as_image_ptr() as *mut _) }
@@ -946,7 +945,6 @@ pub fn impl_widget_trait(ast: &DeriveInput) -> TokenStream {
 
             fn set_deimage<I: ImageExt>(&mut self, image: Option<I>) {
                 assert!(!self.was_deleted());
-                let _old_image = self.deimage();
                 if let Some(image) = image {
                     assert!(!image.was_deleted());
                     unsafe { #set_deimage(self.inner, image.as_image_ptr() as *mut _) }
