@@ -179,7 +179,8 @@ pub fn impl_window_trait(ast: &DeriveInput) -> TokenStream {
                 assert!(std::any::type_name::<T>() != std::any::type_name::<crate::image::TiledImage>(), "TiledImage icons are not supported!");
                 if let Some(mut image) = image {
                     assert!(!image.was_deleted());
-                    unsafe { image.increment_arc(); #set_icon(self.inner, image.as_image_ptr() as *mut _) }
+                    // Shouldn't fail after the previous asserts!
+                    unsafe { #set_icon(self.inner, image.to_rgb().unwrap().as_image_ptr() as *mut _) }
                 } else {
                     unsafe { #set_icon(self.inner, std::ptr::null_mut() as *mut raw::c_void) }
                 }
@@ -331,14 +332,13 @@ pub fn impl_window_trait(ast: &DeriveInput) -> TokenStream {
                 assert!(std::any::type_name::<I>() != std::any::type_name::<crate::image::Image>(), "Images can't be generic!");
                 assert!(std::any::type_name::<I>() != std::any::type_name::<crate::image::TiledImage>(), "TiledImage is not supported!");
                 unsafe {
-                    let image = if let Some(image) = image {
+                    if let Some(image) = image {
                         assert!(image.w() == image.data_w() as i32);
                         assert!(image.h() == image.data_h() as i32);
-                        image.as_image_ptr()
+                        #set_shape(self.inner, image.as_image_ptr() as _)
                     } else {
-                        std::ptr::null()
+                        return;
                     };
-                    #set_shape(self.inner, image as _)
                 }
             }
 
